/*
 * General debug helpers
 */

.pragma library

api.log( qsTr("loading debug...") );

function loaddebugobject() {
    return undefined
}
